==> theme-customizer_0.9-2.tar.gz: theme-customizer-0.9/src/opt/theme-customizer/lang/Spanish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Theme Customizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>Font size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>DEFAULT</source>
        <translation>Por Defecto</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <source>+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <source>+5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>Font colors</source>
        <translation>Colores</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Primary font</source>
        <translation>Primaria</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="242"/>
        <source>Secondary font</source>
        <translation>Secundaria</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>Active font</source>
        <translation>Activa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Disabled font</source>
        <translation>Deshabilitada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="360"/>
        <source>Painted font</source>
        <translation>Coloreada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button font</source>
        <translation type="unfinished">Button font</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button pressed</source>
        <translation type="unfinished">Button pressed</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>&quot;Paint&quot; color</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Icon theme</source>
        <translation>Iconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Homescreen</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Show app shortcut backgrounds</source>
        <translation>Mostrar fondo de íconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Snap-to-grid size</source>
        <translation>Tamaño de ajuste a cuadrícula</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>App shortcut size</source>
        <translation>Tamaño de íconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <source>Web bookmark size</source>
        <translation>Tamaño de favoritos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="721"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <source>Auto-reboot after saving settings</source>
        <translation>Auto-reiniciar después de guardar cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="751"/>
        <location filename="mainwindow.cpp" line="352"/>
        <source>Apply changes</source>
        <translation>Aplicar cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Test</source>
        <translation type="unfinished">Menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>Import fonts from MyDocs</source>
        <translation type="unfinished">Import Fonts from MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="783"/>
        <source>Import all font files from MyDocs</source>
        <translation type="unfinished">Import all font files from MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>About</source>
        <translation type="unfinished">About</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <source>Setting up the theme, please wait...</source>
        <translation>Configurando el tema, por favor espere...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Searching and importing fonts, please wait...</source>
        <translation>Buscando e importando fuentes, por favor espere...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>Save and reboot</source>
        <translation type="unfinished">Save and reboot</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - Importar fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>Desea importar las fuentes desde MyDocs?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>Nota: esta función sólo importará fuentes .ttf y .otf desde la raíz de MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="370"/>
        <source>Importing fonts</source>
        <translation>Importando fuentes</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>About Theme Customizer</source>
        <translation type="unfinished">About Theme Customizer</translation>
    </message>
</context>
</TS>

==> theme-customizer_0.9-7.tar.gz: theme-customizer-0.9/src/opt/theme-customizer/lang/Spanish.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Theme Customizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="120"/>
        <source>Font size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>DEFAULT</source>
        <translation>Por Defecto</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="152"/>
        <source>-5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <source>-3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>-1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="167"/>
        <source>+1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>+3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <source>+5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="192"/>
        <source>Font colors</source>
        <translation>Colores</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="224"/>
        <source>Primary font</source>
        <translation>Primaria</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="242"/>
        <source>Secondary font</source>
        <translation>Secundaria</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>Active font</source>
        <translation>Activa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="278"/>
        <source>Disabled font</source>
        <translation>Deshabilitada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="360"/>
        <source>Painted font</source>
        <translation>Coloreada</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button font</source>
        <translation type="unfinished">
</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Button pressed</source>
        <translation type="unfinished">
</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>&quot;Paint&quot; color</source>
        <translation>Fondo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="437"/>
        <source>Icon theme</source>
        <translation>Iconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Homescreen</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="482"/>
        <source>Show app shortcut backgrounds</source>
        <translation>Mostrar fondo de íconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="508"/>
        <source>Snap-to-grid size</source>
        <translation>Tamaño de ajuste a cuadrícula</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="0"/>
        <source>Widget opacity %</source>
        <translation type="unfinished">
</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="560"/>
        <source>App shortcut size</source>
        <translation>Tamaño de íconos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <source>Web bookmark size</source>
        <translation>Tamaño de favoritos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="721"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <source>Auto-reboot after saving settings</source>
        <translation>Auto-reiniciar después de guardar cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="751"/>
        <location filename="mainwindow.cpp" line="352"/>
        <source>Apply changes</source>
        <translation>Aplicar cambios</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="771"/>
        <source>Test</source>
        <translation type="unfinished">Menu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <source>Import fonts from MyDocs</source>
        <translation type="unfinished">Import Fonts from MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="783"/>
        <source>Import all font files from MyDocs</source>
        <translation type="unfinished">Import all font files from MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>About</source>
        <translation type="unfinished">About</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <source>Setting up the theme, please wait...</source>
        <translation>Configurando el tema, por favor espere...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="7"/>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="8"/>
        <source>Searching and importing fonts, please wait...</source>
        <translation>Buscando e importando fuentes, por favor espere...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="349"/>
        <source>Save and reboot</source>
        <translation type="unfinished">Save and reboot</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - Importar fuente</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>Desea importar las fuentes desde MyDocs?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="362"/>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>Nota: esta función sólo importará fuentes .ttf y .otf desde la raíz de MyDocs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="370"/>
        <source>Importing fonts</source>
        <translation>Importando fuentes</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>About Theme Customizer</source>
        <translation type="unfinished">About Theme Customizer</translation>
    </message>
</context>
</TS>
